{
   "abstract" : "Runs perl-document in external window. No need for config-switching",
   "author" : [
      "Matthias Ries <riesm@cpan.org>"
   ],
   "dynamic_config" : 1,
   "generated_by" : "ExtUtils::MakeMaker version 6.56, CPAN::Meta::Converter version 2.110580",
   "license" : [
      "perl_5"
   ],
   "meta-spec" : {
      "url" : "http://search.cpan.org/perldoc?CPAN::Meta::Spec",
      "version" : "2"
   },
   "name" : "Padre-Plugin-RunPerlExternal",
   "no_index" : {
      "directory" : [
         "t",
         "inc"
      ]
   },
   "prereqs" : {
      "build" : {
         "requires" : {
            "ExtUtils::MakeMaker" : 0
         }
      },
      "configure" : {
         "requires" : {
            "ExtUtils::MakeMaker" : 0
         }
      },
      "runtime" : {
         "requires" : {
            "Padre" : "0.57",
         }
      }
   },
   "release_status" : "stable",
   "resources" : {
      "repository" : {
         "url" : "https://github.com/matthiasries/Padre-Plugin-RunPerlExternal.git"
	}
   },
   "x_screenshots"   => [ 
                         { "thumb" : 'http://img6.imagebanana.com/img/3tndocxg/thumb/Padre_018.png',   "big" : 'http://www.imagebanana.com/view/3tndocxg/Padre_018.png'   },
                         { "thumb" : 'http://img6.imagebanana.com/img/xiglvtu7/thumb/Auswahl_021.png', "big" : 'http://www.imagebanana.com/view/xiglvtu7/Auswahl_021.png' },
                        ],
,
   "version" : "0.51"
}
